function [distance_precision, PASCAL_precision] = precision_plot(distances, overlaps, title, show)
%PRECISION_PLOT
%   Calculates precision for a series of distance thresholds (percentage of
%   frames where the distance to the ground truth is within the threshold).
%   The results are shown in a new figure if SHOW is true.
%
%   Accepts positions and ground truth as Nx2 matrices (for N frames), and
%   a title string.
%
%   Joao F. Henriques, 2014
%   http://www.isr.uc.pt/~henriques/

	
    thresholdSetError = 0:50;
	thresholdSetOverlap = 0:0.05:1;

	%compute precisions
    distance_precision = zeros(1, 51);
	for p = 1:51,
		distance_precision(p) = nnz(distances <= thresholdSetError(p)) / numel(distances);
    end
    
    % calculate PASCAL precision
    PASCAL_precision = zeros(1, 21);
    for p = 1 : 21
        PASCAL_precision(p) = nnz(overlaps >= thresholdSetOverlap(p)) / numel(overlaps);
    end 
	
	%plot the precisions
	if show == 1,
		figure('NumberTitle','off', 'Name',['Distance_Precisions - ' title])
		plot(distance_precision, 'k-', 'LineWidth',2)
		xlabel('Threshold'), ylabel('Precision')
        
        figure('NumberTitle','off', 'Name',['Overlap_Precisions - ' title])
        plot((0 : 0.05 : 1), PASCAL_precision, 'k-', 'LineWidth',2)
        xlabel('Threshold'), ylabel('Precision')
	end
	
end

